classdef dipoleAndMeasureOfStudyErp < pr.dipoleAndMeasureOfStudy
    % holds ERPs from one or several conditions in a linearized way.
    % the first dimension is the linearized version of the ERP for concatenated subset of
    % consitions.
    % the second dimension of value is dipoles.
    properties
        time  = []; % an array that hold the times (in ms) associated with the measure.
    end % properties
     properties (Constant = true)
        numberOfMeasureDimensions = 1; % number of dimensions in measure
    end;% properties
    methods (Access = 'protected')
        function plotMeasureAsArrayInCell(obj, measureAsArrayInCell, title, varargin)
            std_plotcurve(obj.time, measureAsArrayInCell, 'titles', title, 'datatype','erp', varargin{:});
        end;
    end;
    methods
        function obj = dipoleAndMeasureOfStudyErp(STUDY, ALLEEG, varargin) % constructor                     
            superClassArgs = {};
            
            if nargin>1
                superClassArgs{1} = STUDY;
                superClassArgs{2} = ALLEEG;
            end;
            
            if nargin>2
                for i=1:length(varargin) % pass additional parameters in varargin to parent dipoleAndMeasureOfStudy class
                    superClassArgs{2+i} = varargin{i};
                end;
            end;
            
            obj = obj@pr.dipoleAndMeasureOfStudy(superClassArgs{:}); % call the super class constructor
            
            if nargin > 0
                
                [STUDY, erpdataConditionByGroup] = std_readerp(STUDY, ALLEEG,  'clusters', 1);
                
                % perform a 20 Hz lowpass before comparing ERPs, this will reduce the noise and create better
                [b,a] = butter(2,20/(ALLEEG(1).srate / 2),'low');
                
                % combine conditions in each group, then combine groups together
                try
                    for group=1:obj.numberOfGroups
                        
                        % lowpass filter each condition for each group
                        for i=1:size(erpdataConditionByGroup,1)
                            clustinfo.erpdata{i, group} = filtfilt(b,a, double(erpdataConditionByGroup{i, group}));
                        end;
                        
                        combinedConditions{group} = cat(1,clustinfo.erpdata{obj.conditionId,group});
                    end;
                catch exception
                    fprintf('Error in concatenating condition. Some conditions for certain subjects might be missing.\n');
                    disp(exception.message);
                end;
                
                icCombinedErp = cat(2, combinedConditions{:});
                obj.linearizedMeasure = icCombinedErp(:,obj.icIndexForEachDipole);
                obj.time = STUDY.cluster(1).erptimes;
                
                obj = createSubsetInRelationToBrain(obj, obj.relationshipToBrainVolume);
                
                % correct the polarity of ERP measure based on scalpmap normalization polarities.
                % different dipole ERPs are located in the second dimension
                obj.linearizedMeasure = obj.linearizedMeasure .* repmat(obj.scalpmap.normalizationPolarity, size(obj.linearizedMeasure,1),1);
            end;
        end;
    end;
end