classdef dipoleAndMeasureOfStudyErsp < pr.dipoleAndMeasureOfStudy
    % holds ERPs from one or several conditions in a linearized way.
    % the first dimension is the linearized version of the ERSP for concatenated subset of
    % consitions.
    % the second dimension of value is dipoles.
    properties
        time  = []; % an array that hold the times (in ms) associated with the ERSP.
        frequency = []; % an array that hold the frequencies (in Hz) associated with the ERSP.        
    end % properties
    properties (Constant = true)
        numberOfMeasureDimensions = 2;  % number of dimensions in measure
    end;% properties
    methods (Access = 'protected')
       function plotMeasureAsArrayInCell(obj, measureAsArrayInCell, title, varargin)
           std_plottf(obj.time, obj.frequency, measureAsArrayInCell,   'titles', title, varargin{:});
       end;        
    end;
    methods
        function obj = dipoleAndMeasureOfStudyErsp(STUDY, ALLEEG, varargin) % constructor
            superClassArgs = {};
            
            if nargin>1
                superClassArgs{1} = STUDY;
                superClassArgs{2} = ALLEEG;
            end;
            
            if nargin>2
                for i=1:length(varargin) % pass additional parameters in varargin to parent dipoleAndMeasureOfStudy class
                    superClassArgs{2+i} = varargin{i};
                end;
            end;
            
            obj = obj@pr.dipoleAndMeasureOfStudy(superClassArgs{:}); % call the super class constructor
            
            if nargin > 0
                
                [STUDY, erspdataConditionByGroup] = std_readersp(STUDY, ALLEEG,  'clusters', 1);
                
                % for some reason inm the new eeglab version matrices are freq x timez x dipoles
                % (instead of time x freq x dipole), the cod below checks for that and transforms
                % them to this format if necessary
                if size(erspdataConditionByGroup{1,1},1) == length(STUDY.cluster(1).erspfreqs)
                    for i=1:size(erspdataConditionByGroup,1)
                        for j=1:size(erspdataConditionByGroup,2)
                            erspdataConditionByGroup{i,j} = permute( erspdataConditionByGroup{i,j},[2 1 3]);
                        end;
                    end;
                end;
                
                % combine conditions in each group, then combine groups together
                for group=1:obj.numberOfGroups
                    combinedConditions{group} = cat(1, erspdataConditionByGroup{obj.conditionId,group});
                end;
                
                erspdata = cat(3, combinedConditions{:});
                
                % swap dimensions and linearize 3D matrix
                erspdataWithCompsFirst = permute(erspdata,[3 2 1]);
                obj.linearizedMeasure = erspdataWithCompsFirst(obj.icIndexForEachDipole,:)';
                obj.time = STUDY.cluster(1).ersptimes;
                obj.frequency = STUDY.cluster(1).erspfreqs;
                
                obj = createSubsetInRelationToBrain(obj, obj.relationshipToBrainVolume);
            end;
        end;
    end;
end