classdef dipoleAndMeasureOfStudySpec < pr.dipoleAndMeasureOfStudy
    % holds ERPs from one or several conditions in a linearized way.
    % the first dimension is the linearized version of the Spectrum for concatenated subset of
    % consitions.
    % the second dimension of value is dipoles.
    properties
        frequency = [];
        specMeanOverAllIc = [];
    end % properties
     properties (Constant = true)
        numberOfMeasureDimensions = 1; % number of dimensions in measure
    end;% properties
        methods (Access = 'protected')
        function plotMeasureAsArrayInCell(obj, measureAsArrayInCell, title, varargin) 
            specMeanOverAllIcForCondition = getSeparatedConditionsForLinearizedMeasure(obj, obj.specMeanOverAllIc);
            for i=1:length(measureAsArrayInCell)
                measureAsArrayInCell{i} = measureAsArrayInCell{i} + specMeanOverAllIcForCondition{i};
            end;
            std_plotcurve(obj.frequency, measureAsArrayInCell, 'titles', title, 'datatype','spec', varargin{:});
        end;
    end;
    methods
        function obj = dipoleAndMeasureOfStudySpec(STUDY, ALLEEG, varargin) % constructor
            % conditionId is an optional input that specifies which conditions should be included.
            % by default all conditions are included.
            
            superClassArgs = {};
            
            if nargin>1
                superClassArgs{1} = STUDY;
                superClassArgs{2} = ALLEEG;
            end;
            
            if nargin>2
                for i=1:length(varargin) % pass additional parameters in varargin to parent dipoleAndMeasureOfStudy class
                    superClassArgs{2+i} = varargin{i};
                end;
            end;
            
            obj = obj@pr.dipoleAndMeasureOfStudy(superClassArgs{:}); % call the super class constructor
            
            if nargin > 0
                try
                    [STUDY specdata ] = std_readspec(STUDY, ALLEEG, 'clusters', 1);
                    icCombinedSpec = cat(1, specdata{:});
                catch
                    [STUDY clustinfo] = std_readdata(STUDY,ALLEEG,'clusters',STUDY.etc.preclust.clustlevel,'infotype','spec');
                    clustinfo = STUDY.cluster(STUDY.etc.preclust.clustlevel);
                    
                    % combine conditions in each group, then combine groups together
                    for group=1:obj.numberOfGroups
                        combinedConditions{group} = cat(1,clustinfo.specdata{obj.conditionId,group});
                    end;
                    
                    icCombinedSpec = cat(2, combinedConditions{:});
                end;
                
                obj.linearizedMeasure = icCombinedSpec(:,obj.icIndexForEachDipole);
                obj.frequency = STUDY.cluster(1).specfreqs;
                
                % normalized the spectrum by first removing the mean of the spectrum
                % of each component, and then calculating the mean across components and removing it
                % from all (this results is a more or less 'flat' spectrum for each IC).
                % the results is placed in obj.linearizedMeasure. 
                % substracted mean spectrum over all ic is kept in obj.specMeanOverAllIc
                
                specdataEachMeanRemoved = obj.linearizedMeasure - repmat(mean(obj.linearizedMeasure, 1), size(obj.linearizedMeasure,1), 1);
                obj.specMeanOverAllIc= mean(specdataEachMeanRemoved, 2);
                obj.linearizedMeasure = specdataEachMeanRemoved - repmat(obj.specMeanOverAllIc, 1, size(obj.linearizedMeasure,2));
                
                obj = createSubsetInRelationToBrain(obj, obj.relationshipToBrainVolume);
            end;
        end;

    end;
end